==> pixiedust-0.75.tar.gz: pixiedust-0.75/pixiedust/display/chart/renderers/matplotlib/lineChartDisplay.py <==
# -------------------------------------------------------------------------------
# Copyright IBM Corp. 2017
# 
# Licensed under the Apache License, Version 2.0 (the 'License');
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
# http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an 'AS IS' BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# -------------------------------------------------------------------------------

from pixiedust.display.chart.renderers import PixiedustRenderer
from .matplotlibBaseDisplay import MatplotlibBaseDisplay
import matplotlib.pyplot as plt
import mpld3
import numpy as np

@PixiedustRenderer(id="lineChart")
class LineChartDisplay(MatplotlibBaseDisplay):
    def matplotlibRender(self, fig, ax):
        keyFieldValues = self.getKeyFieldValues()
        valueFields = self.getValueFields()
        valueFieldValues = self.getValueFieldValueLists()
        numColumns = len(keyFieldValues)
        for i, valueField in enumerate(valueFields):
            xs = keyFieldValues
            ys = valueFieldValues[i]
            lines = ax.plot(xs, ys, color=self.colormap(1.*i/numColumns), label=valueField, marker='o')
            tooltip = mpld3.plugins.PointLabelTooltip(lines[0], labels=ys)
            if self.has_mpld3:
                mpld3.plugins.connect(fig, tooltip)
        plt.xticks(np.arange(numColumns),self.getKeyFieldLabels())
        plt.xlabel(", ".join(self.getKeyFields()), fontsize=18)

==> pixiedust-0.77.tar.gz: pixiedust-0.77/pixiedust/display/chart/renderers/matplotlib/lineChartDisplay.py <==
# -------------------------------------------------------------------------------
# Copyright IBM Corp. 2017
# 
# Licensed under the Apache License, Version 2.0 (the 'License');
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
# http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an 'AS IS' BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# -------------------------------------------------------------------------------

from pixiedust.display.chart.renderers import PixiedustRenderer
from .matplotlibBaseDisplay import MatplotlibBaseDisplay
import matplotlib.pyplot as plt
import mpld3
import numpy as np

import pixiedust
myLogger = pixiedust.getLogger(__name__)

@PixiedustRenderer(id="lineChart")
class LineChartDisplay(MatplotlibBaseDisplay):
    def matplotlibRender(self, fig, ax):        
        keyFields = self.getKeyFields()
        valueFields = self.getValueFields()
        numColumns = len(keyFields)
        for i, valueField in enumerate(valueFields):
            data = self.getWorkingDataSlice( keyFields[0], valueField, sort = True )
            # xs = data[0]
            xs = xrange(len(data[1]))
            ys = data[1]
            lines = ax.plot(xs, ys, color=self.colormap(1.*i/numColumns), label=valueField, marker='o')
            tooltip = mpld3.plugins.PointLabelTooltip(lines[0], labels=ys)
            if self.has_mpld3:
                mpld3.plugins.connect(fig, tooltip)
        plt.xlabel(", ".join(self.getKeyFields()), fontsize=18)
